@@ -73,6 +73,17 @@ get_y_t_test = function(tau2, t, df) {
   return(to_return)
 }
 
+## functions to return minimum bff for anything greater than small threshold
+get_min_omega_bff = function(omega, bff, cutoff) {
+  idx = which(omega < 0.1)
+  bff = bff[-idx]
+  omega = omega[-idx]
+
+  idx_min = which.min(bff)
+  bff_min = bff[idx_min]
+  omega_min = omega[idx_min]
+  return(c(bff_min, omega_min))
+}
 
 
 
